@@ -1,7 +1,7 @@
 import pandas as pd
 from datetime import datetime
 import os
-
+import openpyxl
 class PTRCalibration:
     TODAY = datetime.today().date()
 
@@ -37,5 +37,9 @@ class PTRCalibration:
         if not os.path.isdir(archive_path):
             os.mkdir(archive_path)
         out = pd.concat(self.frames)
+        try:
+            out.to_excel(os.path.join(extracted_path, f"Excel Extracted Log Files.xlsx"), index=False)
+        except Exception:
+            pass
         out.to_csv(os.path.join(extracted_path, f"Extracted Log Files.csv"), index=False)
         out.to_csv(os.path.join(archive_path, f"Extracted Log Files_{self.TODAY}.csv"), index=False)
\ No newline at end of file
